# *******************************************************
# cmsafe_cxx.mk
# ClearMake include file for building C++ programs using the "CM-safe"
# method of working with cfront-style template instantiation.
# 
# Preferred usage method:
# ClearMake defines an environment variable that expands to "include thisfile".
# In plain make, the environment variable will not ordinarily be defined, and 
# expanding it will have no effect.  Include the following line (omitting 
# comment character and leading whitespace) starting in column 1 at the top of
# your makefile: 
#     $(CLEARCASE_CMSAFE_CXX_LINK_INST) 
#
# Alternate usage:
# You may include this file into a makefile directly, or into a ClearMake 
# Build Options Spec file. 
# You may specify this file as a Build Options Spec via the ClearMake command 
# line option flag -A . 
#
# *******************************************************

# The normal C++ macros are redefined in ClearMake-specific terms below. 
# They reference the actual C++ compiler through the following REAL_C++
# macro. To invoke a C++ compiler other than "CC", you must redefine
# REAL_C++.

REAL_C++ 	 = CC 

# *******************************************************
# *** Macros for C++ translations which use templates *** 
# *******************************************************

# The following macros take the place of the usual C++ compiler.  They each
# invoke a wrapper script instead of the C++ compiler. 

ATRIA_C++ARGS=$@ cfront CM-safe $(REAL_C++)
ATRIA_C++C = ${CLEARCASE_MAKE_CONFIG_DIR}/atria_cxx $(ATRIA_C++ARGS)
ATRIA_C++COMP = ${CLEARCASE_MAKE_CONFIG_DIR}/atria_cxxc $(ATRIA_C++ARGS)
ATRIA_C++LINK = ${CLEARCASE_MAKE_CONFIG_DIR}/atria_cxxl $(ATRIA_C++ARGS)

#
# Note: the 'atria_cxx' script should dispatch to the script specified
# in the ATRIA_C++COMP macro in the case of a single compilation, or to the
# script specified in the ATRIA_C++LINK macro in the case of a program link.
# If for some reason this does not work, you may use the ATRIA_C++COMP and
# ATRIA_C++LINK macros directly for the compile and link phases of the
# build respectively.
# 

# Redefine the usual macros for the C++ compiler to expand to the main
# wrapper.  The goal is to invoke the 'atria_cxx' script in place of any 
# C++ translation in the makefile.

C++C = ${ATRIA_C++C}
C++ = ${ATRIA_C++C}
CXX = ${ATRIA_C++C} 
CCXX = ${ATRIA_C++C}
CCC = ${ATRIA_C++C}
